@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bprojectinterface.h,v 1.3 2004/01/21 10:20:06 trueg Exp $
+ * $Id: k3bprojectinterface.h 419870 2005-05-30 19:29:54Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -19,6 +19,7 @@
 
 #include <dcopobject.h>
 #include <kurl.h>
+#include <kio/global.h>
 
 class K3bDoc;
 
@@ -42,6 +43,33 @@ class K3bProjectInterface : public DCOPObject
   virtual void addUrl( const KURL& url );
   virtual void burn();
 
+  /**
+   * \return the length of the project in blocks (frames).
+   */
+  virtual int length() const;
+
+  /**
+   * \return size of the project in bytes.
+   */
+  virtual KIO::filesize_t size() const;
+
+  virtual const QString& imagePath() const;
+
+  /**
+   * \return A string representation of the project type. One of:
+   * \li "datacd" - Data CD
+   * \li "audiocd" - Audio CD
+   * \li "mixedcd" - Mixed Mode CD
+   * \li "videocd" - Video
+   * \li "emovixcd" - eMovix CD
+   * \li "datadvd" - Data DVD
+   * \li "videodvd" - Video DVD
+   * \li "emovixdvd" - eMovix DVD
+   *
+   * Be aware that this is not the same as K3bDoc::documentType for historical reasons.
+   */
+  virtual QString projectType() const;
+
  private:
   K3bDoc* m_doc;
 };
